#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

entry_points = \
{'console_scripts': ['rftoc = rftoc:main']}

setup(name='rftoc',
      version='0.0.3',
      description='Table of content generator of markdown slides',
      author='OV',
      author_email='olav@vahtras.se',
      url='https://github.com/vahtras/rftoc',
      py_modules=['rftoc'],
      entry_points=entry_points,
     )
